KRButtonSize enum

Inheritance
Available extensions

Values

tiny → const KRButtonSize
small → const KRButtonSize
regular → const KRButtonSize
large → const KRButtonSize

Properties

fontSize → double

Available on KRButtonSize, provided by the ButtonExtension extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
heightSize → double

Available on KRButtonSize, provided by the ButtonExtension extension

no setter
iconPadding → double

Available on KRButtonSize, provided by the ButtonExtension extension

no setter
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
paddingSide → double

Available on KRButtonSize, provided by the ButtonExtension extension

no setter
paddingTopBottom → double

Available on KRButtonSize, provided by the ButtonExtension extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
squerySize → double

Available on KRButtonSize, provided by the ButtonExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<KRButtonSize>
A constant List of the values in this enum, in order of their declaration.