KRTextSize enum

Inheritance
Available extensions

Values

caption → const KRTextSize
body → const KRTextSize
subtitle → const KRTextSize
title → const KRTextSize
headline → const KRTextSize

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double

Available on KRTextSize, provided by the ButtonExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KRTextSize>
A constant List of the values in this enum, in order of their declaration.